<?php

namespace FiloBlu\Rma\Plugin\Model;

use Exception;
use FiloBlu\Rma\Model\Rma\Status\History;
use FiloBlu\Rma\Model\Rma\Status\HistoryFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Rma\Model\Rma\Source\Status;
use Magento\Store\Model\ScopeInterface;
use Psr\Log\LoggerInterface;

/**
 * Class Rma
 * @package FiloBlu\Rma\Plugin\Model
 */
class Rma
{
    /**
     * @var string
     */
    const XML_PATH_RECEIVED_EMAIL_ENABLE = 'sales_email/magento_rma_receive/enabled';
    /**
     * @var HistoryFactory
     */
    protected $historyFactory;

    /**
     * @var LoggerInterface
     */
    protected $logger;
    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * Rma constructor.
     * @param HistoryFactory $historyFactory
     * @param ScopeConfigInterface $scopeConfig
     * @param LoggerInterface $logger
     */
    public function __construct(HistoryFactory $historyFactory,
                                ScopeConfigInterface $scopeConfig,
                                LoggerInterface $logger)
    {
        $this->historyFactory = $historyFactory;
        $this->scopeConfig = $scopeConfig;
        $this->logger = $logger;
    }

    /**
     * @param \Magento\Rma\Model\Rma $subject
     * @param \Magento\Rma\Model\Rma|false $result
     * @return bool
     */
    public function afterSaveRma(\Magento\Rma\Model\Rma $subject, $result)
    {
        if ($result === false) {
            return $result;
        }

        try {

            $storeId = $subject->getStoreId();

            if (!boolval($this->getConfigValue(self::XML_PATH_RECEIVED_EMAIL_ENABLE, $storeId))) {
                return $result;
            }

            $status = $result->getStatus();

            switch ($status) {
                case  Status::STATE_RECEIVED:

                    /** @var $result \Magento\Rma\Model\Rma */
                    /** @var $statusHistory History */
                    $statusHistory = $this->historyFactory->create();
                    $statusHistory->setRmaEntityId($result->getEntityId());
                    $statusHistory->sendReceivedEmail();
                    break;
            }

        } catch (Exception $e) {
            $this->logger->critical($e);
            return $result;
        }

        return $result;
    }

    /**
     * Return store configuration value
     *
     * @param string $path
     * @param int $storeId
     * @return mixed
     */
    protected function getConfigValue($path, $storeId)
    {
        return $this->scopeConfig->getValue(
            $path,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }
}

